Enum List

pub enum List<'t, T> {
    Pair(T, &'t List<'t, T>),
    Null,
}
Cons list. Only works with normal references. That’s because making it generic for the reference/container type appears unworkable, even though feasible in principle, due to requiring explicit type parameters on every single cons call. The solution will be to generate the code for versions using Rc, Arc or whatever when needed. (Or, use dyn?, or perhaps/probably rather, enum.)

Variants



Pair(T, &'t List<'t, T>)



Null

Implementations

Source

impl<'t, T> List<'t, T>

pub fn len(&self) -> usize

pub fn first(&self) -> Option<&T>

pub fn rest(&self) -> Option<&List<'_, T>>

pub fn last(&self) -> Option<&T>

pub fn as_ref_vec(&self) -> Vec<&T>

A Vec of all the values as references.

pub fn to_vec(&self) -> Vec<T>
where T: Clone,

Source

impl<'t, T: PartialEq> List<'t, T>

pub fn contains(&self, val: &T) -> bool

Report whether a List contains a particular value.

Source

impl<'t, K: PartialEq, V> List<'t, (K, V)>

pub fn alist_get(&self, key: &K) -> Option<&V>

In a List of (K, V) pairs, get the first V for which the K == key.